@@ -49,7 +49,7 @@ c       real*8 Zfirst       ! to keep first interaction slant depth
         real*8  KEminCas      ! //          (for em-cascade)
         real*8  KEmin2        ! min kinetic energy to be tracked.  for skeleton/flesh use.
         real*8  KEminCas2     ! for skeleton/flesh use.
-	real*8  Ethin         ! Thin sampling threshold.
+	real*8  Ethin(2)      ! Thin sampling threshold.
 	real*8 Beta  !  v/c for MovedTrack; given if TimeStrucrue=T.
 	record /magfield/ Mag
 	integer MaxPtcl
