@@ -48,8 +48,14 @@ c                 save the initial seed of random number
             call cinitStack
             call cpush(incident)
          endif
-         call csetMolUnit
-         call chookBgEvent    ! user hook for each event beginning
+         if(Job .eq. 'newflesh') then
+c                  this may be used always; but next one is original
+            call chookBgEvent   ! user hook for each event beginning
+            call csetMolUnit    ! for newflesh, primary is fixed above
+         else
+            call csetMolUnit
+            call chookBgEvent   ! user hook for each event beginning
+         endif
 
          call ctrackingAll
          if(Job .ne. 'newflesh') then
@@ -75,11 +81,13 @@ c         set  Moliere unit at each observtion depth (2r.l above along primary)
       call cqIncident(inci, angle)
 
       do  i = 1, NoOfSites
-         call cgetMoliereU(ObsSites(i).pos.depth, inci.vec.coszenith, 
+c         call cgetMoliereU(ObsSites(i).pos.depth, inci.vec.coszenith, ! bef v7.
+          call cgetMoliereU(ObsSites(i).pos.depth, -angle.r(3),
      *    ObsSites(i).mu)
       enddo
       do i = 1, NoOfASSites
-         call cgetMoliereU(ASObsSites(i).pos.depth, inci.vec.coszenith, 
+c         call cgetMoliereU(ASObsSites(i).pos.depth, inci.vec.coszenith, 
+          call cgetMoliereU(ASObsSites(i).pos.depth, -angle.r(3),
      *       ASObsSites(i).mu)
       enddo
       end
