@@ -50,8 +50,8 @@ c         no coord. conv. is made unless the ptcl is at observation
 c         level.
 c 
 c           convert time into ns
-         if(TimeStructure .and. ObsPlane .ge. 1 .and. ObsPlane .le. 2) 
-     *    then
+         if(TimeStructure .and. abs(ObsPlane) .ge. 1
+     *                    .and. abs(ObsPlane) .le. 2)  then
             oTrack.t = ( oTrack.t  - ObsSites(oTrack.where).minitime )
      *              /c *Tonsec
          endif
