@@ -419,7 +419,7 @@ c                convert it in real length (m).  In this process,
 c                path truncation may occur (if the particle is
 c                going upward, and there is very thin air there,
 c                then the given thickness may not be realized.
-c                Or if the lenght is too large and accuracy 
+c                Or if the length is too large and accuracy 
 c                of convesion is not enough due to the earch
 c                curverture)
 c                If the decay process exists, we compare the length
@@ -474,7 +474,6 @@ c
       integer i, jcut
 c     
        minlen = Infty + Infty
-
 c              get vertical height
        h = TrackBefMove.pos.height
        do i = 1, NumberOfInte
@@ -511,7 +510,7 @@ c      if(leng .ge. Infty) then
 c         ProcessNo = 1
 c         IntInfArray(1).length = 1.e5
 c      endif         
-      if(IntInfArray(ProcessNo).decay .or. jcut .ne. 0) then
+      if(IntInfArray(ProcessNo).decay ) then
 c         In the case  of muon, if individual knockon process  
 c       is neglected (by parameter setting or with high Emin)
 c       the length could be quite large (say, 6000  km).
@@ -545,16 +544,25 @@ c        an observation depth.
       real*8 leng, thick
 c
       call cmaxMovLen(leng, thick)
-c//////////
-c      write(*,*) ' -- maxlen=',leng, ' thick=',thick,
-c     *  ' proce no=',ProcessNo, ' proc=',
-c     *    IntInfArray(ProcessNo).process,
-c     * ' int leng=',  IntInfArray(ProcessNo).length 
-c////////////
       if(leng .lt. IntInfArray(ProcessNo).length ) then
          MoveStat = Truncated
          IntInfArray(ProcessNo).length = leng
          IntInfArray(ProcessNo).thickness  = thick
+c//////////
+c      else
+c         if(TrackBefMove.pos.height .eq. 100.d3 .and.
+c     *     IntInfArray(ProcessNo).thickness .lt. 10.0d0) then
+c            write(*,*) 100.d3- IntInfArray(ProcessNo).length, 
+c     *      IntInfArray(ProcessNo).thickness
+c         endif
+c         write(*,*) 'thru: maxlen=',leng, ' thick=',thick,
+c     *  ' proce no=',ProcessNo, ' proc=',
+c     *    IntInfArray(ProcessNo).process,
+c     *    ' Bef H=',TrackBefMove.pos.height,
+c     *    ' Bef D=',TrackBefMove.pos.depth,
+c     * ' int leng=',  IntInfArray(ProcessNo).length, 
+c    * ' int thick=',  IntInfArray(ProcessNo).thickness
+c////////////
       endif
       end
 c      *************** for same model, we must use simple super position for heavy
